"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/config/config.ts
var config_exports = {};
__export(config_exports, {
  ApplicationConfigEnvSchema: () => ApplicationConfigEnvSchema,
  activeConfig: () => activeConfig,
  config: () => config,
  createConfig: () => createConfig,
  createEnv: () => createEnv
});
module.exports = __toCommonJS(config_exports);
var import_node_fs2 = require("fs");
var import_node_path2 = require("path");
var import_dotenv = __toESM(require("dotenv"), 1);
var import_lilconfig = require("lilconfig");
var import_ts_deepmerge = require("ts-deepmerge");
var import_zod = require("zod");

// src/utils/path.ts
var import_node_fs = require("fs");
var import_node_path = require("path");
function findProjectRoot(startDir) {
  let currentDir = startDir;
  while (currentDir !== (0, import_node_path.parse)(currentDir).root) {
    if ((0, import_node_fs.existsSync)((0, import_node_path.join)(currentDir, "package.json"))) {
      return currentDir;
    }
    currentDir = (0, import_node_path.dirname)(currentDir);
  }
  throw new Error("Unable to find project root");
}

// src/config/config.ts
var ApplicationConfigSchema = import_zod.z.object({
  application: import_zod.z.object({
    id: import_zod.z.string(),
    displayName: import_zod.z.string()
  }),
  portalGql: import_zod.z.string().url().optional(),
  portalRest: import_zod.z.string().url().optional(),
  thegraphGql: import_zod.z.string().url().optional(),
  hasuraGql: import_zod.z.string().url().optional(),
  nodeJsonRpc: import_zod.z.string().url().optional()
});
var ConfigSchema = import_zod.z.object({
  framework: import_zod.z.string(),
  instance: import_zod.z.string().url(),
  workspace: import_zod.z.object({
    id: import_zod.z.string(),
    displayName: import_zod.z.string()
  }),
  childWorkspace: import_zod.z.object({
    id: import_zod.z.string(),
    displayName: import_zod.z.string()
  }).optional(),
  defaultApplication: import_zod.z.object({
    id: import_zod.z.string(),
    displayName: import_zod.z.string()
  }),
  applications: import_zod.z.record(import_zod.z.string(), ApplicationConfigSchema).optional()
});
var ConfigEnvSchema = ConfigSchema.extend({
  pat: import_zod.z.string(),
  appUrl: import_zod.z.string().url().optional(),
  hasuraAdminSecret: import_zod.z.string().optional(),
  sessionSecret: import_zod.z.string().min(32).optional()
});
var EnvSchema = import_zod.z.object({
  SETTLEMINT_PAT_TOKEN: import_zod.z.string(),
  SETTLEMINT_HASURA_GQL_ADMIN_SECRET: import_zod.z.string().optional(),
  NEXT_PUBLIC_SETTLEMINT_APP_URL: import_zod.z.string().url().optional(),
  SETTLEMINT_SESSION_SECRET: import_zod.z.string().min(32).optional()
});
var ApplicationConfigEnvSchema = ApplicationConfigSchema.extend({
  pat: import_zod.z.string(),
  appUrl: import_zod.z.string().url().optional(),
  hasuraAdminSecret: import_zod.z.string().optional()
});
function config() {
  const config2 = parseConfig();
  if (!config2) {
    return void 0;
  }
  return ConfigEnvSchema.parse({
    ...config2,
    pat: process.env.SETTLEMINT_PAT_TOKEN,
    appUrl: process.env.NEXT_PUBLIC_SETTLEMINT_APP_URL,
    hasuraAdminSecret: process.env.SETTLEMINT_HASURA_GQL_ADMIN_SECRET,
    authSecret: process.env.SETTLEMINT_AUTH_SECRET,
    sessionSecret: process.env.SETTLEMINT_SESSION_SECRET
  });
}
function parseConfig() {
  const explorer = (0, import_lilconfig.lilconfigSync)("settlemint");
  const result = explorer.search();
  if (!result) {
    return void 0;
  }
  return ConfigSchema.parse(result.config);
}
async function createConfig(config2) {
  const defaultConfig = {};
  const preConfiguredConfig = (0, import_ts_deepmerge.merge)(defaultConfig, config2);
  const existingConfig = await parseConfig();
  const mergedConfig = existingConfig ? (0, import_ts_deepmerge.merge)(existingConfig, preConfiguredConfig) : preConfiguredConfig;
  const validatedMergedConfig = ConfigSchema.parse(mergedConfig);
  const projectRoot = findProjectRoot(process.cwd());
  const configPath = (0, import_node_path2.join)(projectRoot, ".settlemintrc.json");
  (0, import_node_fs2.writeFileSync)(configPath, JSON.stringify(validatedMergedConfig, null, 2));
}
var escapeNewlines = (str) => str.replace(/\n/g, "\\n");
var format = (key, value) => `${key}=${escapeNewlines(value)}`;
async function createEnv(env) {
  const projectRoot = findProjectRoot(process.cwd());
  const envPath = (0, import_node_path2.join)(projectRoot, ".env.local");
  let dotEnv = {};
  try {
    dotEnv = import_dotenv.default.parse((0, import_node_fs2.readFileSync)(envPath, "utf-8"));
  } catch (e) {
  }
  const mergedEnv = (0, import_ts_deepmerge.merge)(dotEnv, env);
  const validatedMergedEnv = EnvSchema.parse(mergedEnv);
  const contents = Object.entries(validatedMergedEnv).filter(([_, value]) => value !== void 0).map(([key, value]) => format(key, value)).join("\n");
  (0, import_node_fs2.writeFileSync)(envPath, contents);
  import_dotenv.default.config({
    path: [".env.local", ".env"],
    override: true
  });
}
function activeConfig() {
  const cfg = config();
  if (!cfg) {
    console.warn("No configuration found, please run settlemint connect");
    return void 0;
  }
  const applications = cfg.applications ?? {};
  const env = process.env.SETTLEMINT_APPLICATION ?? cfg?.defaultApplication.id;
  if (!env || Object.keys(applications).length === 0) {
    throw new Error(
      "No environment found, either set SETTLEMINT_APPLICATION or define a default environment in your .settlemintrc.json file"
    );
  }
  const envConf = applications[env];
  if (!envConf) {
    throw new Error(`No application found for ${env}, please run \`settlemint connect\``);
  }
  return ApplicationConfigEnvSchema.parse({
    ...envConf,
    pat: cfg.pat,
    appUrl: cfg.appUrl,
    hasuraAdminSecret: cfg.hasuraAdminSecret
  });
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  ApplicationConfigEnvSchema,
  activeConfig,
  config,
  createConfig,
  createEnv
});
//# sourceMappingURL=config.cjs.map